# Copyright (c) 2022 CESNET
# 
# This software is released under the MIT License.
# https://opensource.org/licenses/MIT

from .ext import NRCommonMetadataExt

__version__ = '4.0.0.dev15'

__all__ = ('__version__', 'NRCommonMetadataExt')
